<?php
/**
 * @Manage Columns
 * @return
 *
 */
 
if (!class_exists('post_type_location')) {

    class post_type_location {

        // The Constructor
        public function __construct() {
        
            add_filter('manage_location_posts_columns', array(&$this, 'cs_location_columns_add'));
            add_action('manage_location_posts_custom_column', array(&$this, 'cs_location_columns'), 10, 2);
			add_action('init', array(&$this, 'cs_location_register'));
			add_action('init', array(&$this, 'cs_location_categories'));
		}

		function cs_location_columns_add($columns) {
			$columns['timing'] =esc_html__('Timing','cs_frame');
			return $columns;
		}

		function cs_location_columns($name) {
			global $post;
			switch ($name) {
				
				case 'timing':
					$start_time = get_post_meta( $post->ID, 'cs_location_start_time', true );
					$end_time = get_post_meta( $post->ID, 'cs_location_end_time', true );
					$all_day = get_post_meta( $post->ID, 'cs_location_all_day', true );
					
					$start_time = date_i18n(get_option('time_format'), strtotime($start_time));
					$end_time = date_i18n(get_option('time_format'), strtotime($end_time));
					
					if( $all_day == 'on' ) {
						esc_html_e('All day', 'cs_frame');
					} else if( $start_time <> '' && $end_time <> '' ) {
						echo esc_attr($start_time . ' - ' . $end_time);
					} else if( $start_time <> '' && $end_time == '' ) {
						echo esc_attr($start_time);
					} else {
						echo '-';
					}
				break;
			}
		}

		/**
		 * @Register Post Type
		 * @return
		 *
		 */
		function cs_location_register() {
			
			$labels = array(
				'name' => esc_html__('Location','cs_frame'),
				'all_items' => esc_html__('Location','cs_frame'),
				'add_new_item' => esc_html__('Add New Location','cs_frame'), 
				'edit_item' => esc_html__('Edit Location','cs_frame'), 
				'new_item' => esc_html__('New Location Item','cs_frame'),
				'add_new' => esc_html__('Add New Location','cs_frame'),
				'view_item' => esc_html__('View Location Item','cs_frame'), 
				'search_items' => esc_html__('Search Location','cs_frame'), 
				'not_found' => esc_html__('Nothing found','cs_frame'),  
				'not_found_in_trash' => esc_html__('Nothing found in Trash','cs_frame'),
				'parent_item_colon' => ''
			);
			
			$args = array(
				'labels' => $labels,
				'public' => true,
				'publicly_queryable' => true,
				'show_ui' => true,
				'query_var' => true,
				'menu_icon' => 'dashicons-book',
				'rewrite' => true,
				'capability_type' => 'post',
				'has_archive' => true,
				'map_meta_cap' => true,
				'hierarchical' => false,
				'menu_position' => null,
				'can_export' => true,
				'supports' => array('title'),
			); 
			register_post_type( 'location' , $args );

		}
		
		function cs_location_categories() { 
			$labels = array(
				'name' => esc_html__('Country','cs_frame'), 
				'search_items' => esc_html__('Search Country','cs_frame'), 
				'edit_item' => esc_html__('Edit Country','cs_frame'), 
				'update_item' => esc_html__('Update Country','cs_frame'), 
				'add_new_item' => esc_html__('Add Country','cs_frame'), 
				'menu_name' => esc_html__('Country','cs_frame'), 
			);
			register_taxonomy('location-category',array('location'), array(
				'hierarchical' => true,
				'labels' => $labels,
				'show_ui' => true,
				'query_var' => true,
				'rewrite' => array( 'slug' => 'location-category' ),
			));
		}
	}
	
	return new post_type_location();
}
