<?php
add_action('after_setup_theme', 'cs_theme_setup');

function cs_theme_setup() {
    global $wpdb;
    /* Add theme-supported features. */
    // Make theme available for translation
    // Translations can be filed in the /languages/ directory
    load_theme_textdomain('logistic', get_template_directory() . '/languages');
    if (!isset($content_width)) {
        $content_width = 1170;
    }
    $args = array(
        'default-color' => '',
        'flex-width' => true,
        'flex-height' => true,
        'default-image' => '',	
    );
	add_theme_support('custom-background', $args);
    add_theme_support('custom-header', $args);
    // This theme uses post thumfbnails
    add_theme_support('post-thumbnails');
    // Add default posts and comments RSS feed links to head
    add_theme_support('automatic-feed-links');
    add_theme_support("title-tag");
	add_editor_style( array( 'assets/css/editor_style.css', '', get_template_directory_uri() ) );
    /* Add custom actions. */
    global $pagenow;
    if ( ! session_id() ) {
        add_action('init', 'session_start');
    }
    if ( ! get_option('cs_font_list') || ! get_option('cs_font_attribute') ) {
        cs_get_google_init_arrays();
    }
    if (is_admin() && isset($_GET['activated']) && $pagenow == 'themes.php') {
        if (!get_option('cs_theme_options')) {
            add_action('init', 'cs_activation_data');
        }
        	
        if (!get_option('cs_theme_options')) {
            wp_redirect(admin_url('themes.php?page=tgmpa-install-plugins'));
        }
	}

    add_action('admin_enqueue_scripts', 'cs_admin_scripts_enqueue');
    //wp_enqueue_scripts
    add_action('wp_enqueue_scripts', 'cs_front_scripts_enqueue');
    /* Add custom filters. */
    add_filter('widget_text', 'do_shortcode');
    add_filter('the_password_form', 'cs_password_form');
    add_filter('wp_page_menu', 'cs_add_menuid');
    add_filter('wp_page_menu', 'cs_remove_div');
    add_filter('nav_menu_css_class', 'cs_add_parent_css', 10, 2);
    add_filter('pre_get_posts', 'cs_change_query_vars');
    define('ICL_DONT_LOAD_LANGUAGE_SELECTOR_CSS', true);
}

require_once ABSPATH . '/wp-admin/includes/file.php';

// Default Gallery
add_action('admin_footer-post.php', 'cs_remove_gallery_setting_div');
if (!function_exists('cs_remove_gallery_setting_div')) {

    function cs_remove_gallery_setting_div() {
        echo '
		<style type="text/css">
			.media-sidebar .gallery-settings{
				display:none;
			}
		</style>';
    }
}

add_filter('post_gallery', 'cs_custom_gallery', 10, 2);

function cs_custom_gallery($output, $attr) {
    global $post;

    if (isset($attr['orderby'])) {
        $attr['orderby'] = sanitize_sql_orderby($attr['orderby']);
        if (!$attr['orderby'])
            unset($attr['orderby']);
    }

    extract(shortcode_atts(array(
        'order' => 'ASC',
        'orderby' => 'menu_order ID',
        'id' => $post->ID,
        'itemtag' => 'dl',
        'icontag' => 'dt',
        'captiontag' => 'dd',
        'include' => '',
        'exclude' => ''
    ), $attr));

    $id = intval($id);
    if ('RAND' == $order)
        $orderby = 'none';

    if (!empty($include)) {
        $include = preg_replace('/[^0-9,]+/', '', $include);
        $_attachments = get_posts(array('include' => $include, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby));

        $attachments = array();
        foreach ($_attachments as $key => $val) {
            $attachments[$val->ID] = $_attachments[$key];
        }
    }

    if (empty($attachments))
        return '';

    // Here's your actual output, you may customize it to your need
//cs_prettyphoto_enqueue();
    $output = "<div class=\"cs-gallery lightbox default-gallery\">\n";
   // Now you loop through each attachment
    foreach ($attachments as $id => $attachment) {
        $img_full = wp_get_attachment_image_src($id, 'full');
        $img = wp_get_attachment_image_src($id, 'cs_media_6');

        $output .= "<article class=\"col-md-3\">\n";
        $output .= "<figure>\n";
        $output .= "<img src=\"{$img[0]}\" alt=\"image\" />\n";
        $output .= "<figcaption><a data-rel=\"prettyPhoto[0]\" href=\"{$img_full[0]}\"><i class=\"icon-plus7\"></i></a></figcaption>\n";
        $output .= "</figure>\n";
        $output .= "</article>\n";
		
    }
	
	$output .= "</div>\n";

    return $output;
}

function cs_remove_dimensions_avatars($avatar) {
    $avatar = preg_replace("/(width|height)=\'\d*\'\s/", "", $avatar);
    return $avatar;
}

add_filter('get_avatar', 'cs_remove_dimensions_avatars', 10);

function cs_ensure_ajaxurl() {
    if (is_admin())
        return;
    ?>
    <script type="text/javascript"> //<![CDATA[ var admin_url = <?php echo admin_url('admin-ajax.php'); ?>; //]]> </script>
    <?php
}

// tgm class for (internal and WordPress repository) plugin activation start
require_once get_template_directory() . '/include/theme-components/cs-activation-plugins/tgm_plugin_activation.php';
add_action('tgmpa_register', 'cs_register_required_plugins');

function cs_register_required_plugins() {
    /**
     * Array of plugin arrays. Required keys are name and slug.
     * If the source is NOT from the .org repo, then source is also required.
     */
    $plugins = array(
        // This is an example of how to include a plugin from the WordPress Plugin Repository
        array(
            'name' => esc_html__('Revolution Slider', 'logistic'),
            'slug' => 'revslider',
			'source' => 'http://chimpgroup.com/wp-demo/download-plugin/revslider.zip', 
            'required' => true,
            'version' => '',
            'force_activation' => false,
            'force_deactivation' => false,
            'external_url' => '',
        ),
		array(
            'name' => esc_html__('CS Framework', 'logistic'),
            'slug' => 'cs-framework',
            'source' => get_template_directory_uri() . '/include/theme-components/cs-activation-plugins/cs-framework.zip',
            'required' => true,
            'version' => '',
            'force_activation' => false,
            'force_deactivation' => false,
            'external_url' => '',
        ),
		array(
            'name' => 'Loco translate',
            'slug' => 'loco-translate',
            'required' => true,
            'version' => '',
            'force_activation' => false,
            'force_deactivation' => false,
            'external_url' => '',
        ),
        
        array(
            'name' => 'Envato Wordpress Toolkit',
            'slug' => 'envato-wordpress-toolkit',
            'source' => 'https://github.com/envato/envato-wordpress-toolkit/archive/master.zip',
            'external_url' => '',
            'required' => false,
        )
    );
    // Change this to your theme text domain, used for internationalising strings
    $theme_text_domain = 'logistic';
    /**
     * Array of configuration settings. Amend each line as needed.
     * If you want the default strings to be available under your own theme domain,
     * leave the strings uncommented.
     * Some of the strings are added into a sprintf, so see the comments at the
     * end of each line for what each argument will be.
     */
    $config = array(
		'id'           => 'tgmpa',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'parent_slug'  => 'themes.php',            // Parent menu slug.
		'capability'   => 'edit_theme_options',    // Capability needed to view plugin install page, should be a capability associated with the parent menu used.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
        
		'strings'      => array(
			'page_title'                      => esc_html__( 'Install Required Plugins', 'logistic' ),
			'menu_title'                      => esc_html__( 'Install Plugins', 'logistic' ),
			'installing'                      => esc_html__( 'Installing Plugin: %s', 'logistic' ), // %s = plugin name.
			'oops'                            => esc_html__( 'Something went wrong with the plugin API.', 'logistic' ),
			'notice_can_install_required'     => _n_noop(
				'This theme requires the following plugin: %1$s.',
				'This theme requires the following plugins: %1$s.',
				'logistic'
			), // %1$s = plugin name(s).
			'notice_can_install_recommended'  => _n_noop(
				'This theme recommends the following plugin: %1$s.',
				'This theme recommends the following plugins: %1$s.',
				'logistic'
			), // %1$s = plugin name(s).
			'notice_cannot_install'           => _n_noop(
				'Sorry, but you do not have the correct permissions to install the %1$s plugin.',
				'Sorry, but you do not have the correct permissions to install the %1$s plugins.',
				'logistic'
			), // %1$s = plugin name(s).
			'notice_ask_to_update'            => _n_noop(
				'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.',
				'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.',
				'logistic'
			), // %1$s = plugin name(s).
			'notice_ask_to_update_maybe'      => _n_noop(
				'There is an update available for: %1$s.',
				'There are updates available for the following plugins: %1$s.',
				'logistic'
			), // %1$s = plugin name(s).
			'notice_cannot_update'            => _n_noop(
				'Sorry, but you do not have the correct permissions to update the %1$s plugin.',
				'Sorry, but you do not have the correct permissions to update the %1$s plugins.',
				'logistic'
			), // %1$s = plugin name(s).
			'notice_can_activate_required'    => _n_noop(
				'The following required plugin is currently inactive: %1$s.',
				'The following required plugins are currently inactive: %1$s.',
				'logistic'
			), // %1$s = plugin name(s).
			'notice_can_activate_recommended' => _n_noop(
				'The following recommended plugin is currently inactive: %1$s.',
				'The following recommended plugins are currently inactive: %1$s.',
				'logistic'
			), // %1$s = plugin name(s).
			'notice_cannot_activate'          => _n_noop(
				'Sorry, but you do not have the correct permissions to activate the %1$s plugin.',
				'Sorry, but you do not have the correct permissions to activate the %1$s plugins.',
				'logistic'
			), // %1$s = plugin name(s).
			'install_link'                    => _n_noop(
				'Begin installing plugin',
				'Begin installing plugins',
				'logistic'
			),
			'update_link' 			  => _n_noop(
				'Begin updating plugin',
				'Begin updating plugins',
				'logistic'
			),
			'activate_link'                   => _n_noop(
				'Begin activating plugin',
				'Begin activating plugins',
				'logistic'
			),
			'return'                          => esc_html__( 'Return to Required Plugins Installer', 'logistic' ),
			'plugin_activated'                => esc_html__( 'Plugin activated successfully.', 'logistic' ),
			'activated_successfully'          => esc_html__( 'The following plugin was activated successfully:', 'logistic' ),
			'plugin_already_active'           => esc_html__( 'No action taken. Plugin %1$s was already active.', 'logistic' ),  // %1$s = plugin name(s).
			'plugin_needs_higher_version'     => esc_html__( 'Plugin not activated. A higher version of %s is needed for this theme. Please update the plugin.', 'logistic' ),  // %1$s = plugin name(s).
			'complete'                        => esc_html__( 'All plugins installed and activated successfully. %1$s', 'logistic' ), // %s = dashboard link.
			'contact_admin'                   => esc_html__( 'Please contact the administrator of this site for help.', 'logistic' ),

			'nag_type'                        => 'updated', // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
		),
		
	);
    tgmpa($plugins, $config);
}

//Blog Detail Full Width
add_image_size('cs_media_1', 1170, 490, true);
//Blog Large, Blog Detail, Service Detail
add_image_size('cs_media_2', 870, 490, true);
//Fleet Detail
add_image_size('cs_media_3', 670, 503, true);
//Services
//Services Listing
add_image_size('cs_media_4', 372, 209, true);
//Fleet Listing
//Fleet Grid
add_image_size('cs_media_5', 370, 278, true);
//Blog Medium 
add_image_size('cs_media_6', 200, 115, true);


// Next post link class
if (!function_exists('cs_posts_link_next_class')) {

    function cs_posts_link_next_class($format) {
        $format = str_replace('href=', 'class="pix-nextpost" href=', $format);
        return $format;
    }

    add_filter('next_post_link', 'cs_posts_link_next_class');
}

// prev post link class
if (!function_exists('cs_posts_link_prev_class')) {

    function cs_posts_link_prev_class($format) {
        $format = str_replace('href=', 'class="pix-prevpost" href=', $format);
        return $format;
    }

    add_filter('previous_post_link', 'cs_posts_link_prev_class');
}
// stripslashes / htmlspecialchars for theme option save start
if (!function_exists('cs_stripslashes_htmlspecialchars')) {

    function cs_stripslashes_htmlspecialchars($value) {
        $value = is_array($value) ? array_map('cs_stripslashes_htmlspecialchars', $value) : stripslashes(htmlspecialchars($value));
        return $value;
    }
}
/*
 * Hex Color 
 */
function cs_hex2rgb($hex) {
    $hex = str_replace("#", "", $hex);
    if (strlen($hex) == 3) {
        $r = hexdec(substr($hex, 0, 1) . substr($hex, 0, 1));
        $g = hexdec(substr($hex, 1, 1) . substr($hex, 1, 1));
        $b = hexdec(substr($hex, 2, 1) . substr($hex, 2, 1));
    } else {
        $r = hexdec(substr($hex, 0, 2));
        $g = hexdec(substr($hex, 2, 2));
        $b = hexdec(substr($hex, 4, 2));
    }
    $rgb = array($r, $g, $b);
    return $rgb;
}
/*
 * End Color 
 */

if ( ! function_exists('cs_require_theme_files') ) {
    
	function cs_require_theme_files( $cs_path = '' ) {
		
		global $wp_filesystem;
					
		$backup_url = '';
		
		if ( false === ($creds = request_filesystem_credentials( $backup_url, '', false, false, array() ) ) ) {
		
			return true;
		}

		if ( ! WP_Filesystem($creds) ) {
			request_filesystem_credentials( $backup_url, '', true, false, array() );
			return true;
		}
		
		$cs_sh_front_dir = trailingslashit( get_template_directory() ) . $cs_path;
		
		$cs_all_f_list = $wp_filesystem->dirlist( $cs_sh_front_dir );
		
		if( is_array( $cs_all_f_list )  && sizeof( $cs_all_f_list ) > 0 ) {
			
			foreach( $cs_all_f_list as $file_key => $file_val ) {
				
				if( isset( $file_val['name'] ) ) {
					
					$cs_file_name = $file_val['name'];
					
					$cs_ext = pathinfo( $cs_file_name, PATHINFO_EXTENSION );
					
					if( $cs_ext == 'php' ) {
						require_once trailingslashit( get_template_directory() ) . $cs_path . $cs_file_name;
					}
				}
			}
		}		
	}
}

// installing tables on theme activating start
global $pagenow;
// Admin scripts enqueue
function cs_admin_scripts_enqueue() {
    if (is_admin()) {
        $template_path = get_template_directory_uri() . '/include/assets/scripts/media_upload.js';
        wp_enqueue_media();
        wp_enqueue_script('my-upload', $template_path, array('jquery', 'media-upload', 'thickbox', 'jquery-ui-droppable', 'jquery-ui-datepicker', 'jquery-ui-slider', 'wp-color-picker'));
        wp_enqueue_script('datetimepicker1_js', get_template_directory_uri() . '/include/assets/scripts/jquery_datetimepicker.js', '', '', true);
        wp_enqueue_script('admin_theme-option-fucntion_js', get_template_directory_uri() . '/include/assets/scripts/theme_option_fucntion.js', '', '', true);
        wp_enqueue_style('custom_wp_admin_style', get_template_directory_uri() . '/include/assets/css/admin_style.css');
        wp_enqueue_script('custom_wp_admin_script', get_template_directory_uri() . '/include/assets/scripts/cs_functions.js');
        wp_enqueue_script('custom_page_builder_wp_admin_script', get_template_directory_uri() . '/include/assets/scripts/cs_page_builder_functions.js');
        wp_enqueue_script('bootstrap.min_script', get_template_directory_uri() . '/include/assets/scripts/bootstrap.min.js');
        wp_enqueue_style('wp-color-picker');
        // load icon moon
        wp_enqueue_script('fonticonpicker_js', get_template_directory_uri() . '/include/assets/icon/js/jquery.fonticonpicker.min.js');
        wp_enqueue_style('fonticonpicker_css', get_template_directory_uri() . '/include/assets/icon/css/jquery.fonticonpicker.min.css');
        wp_enqueue_style('iconmoon_css', get_template_directory_uri() . '/include/assets/icon/css/iconmoon.css');
        wp_enqueue_style('fonticonpicker_bootstrap_css', get_template_directory_uri() . '/include/assets/icon/theme/bootstrap-theme/jquery.fonticonpicker.bootstrap.css');
    }
}

require_once get_template_directory() . '/include/metaboxes/classes/cs_meta_fields_render.php';
require_once get_template_directory() . '/include/helpers/notification-helper.php';

require_once get_template_directory() . '/include/page_builder.php';
require_once get_template_directory() . '/include/metaboxes/general-settings.php';
require_once get_template_directory() . '/include/metaboxes/post_meta.php';
require_once get_template_directory() . '/include/metaboxes/page_meta.php';
#Blogs
require_once get_template_directory() . '/cs-templates/blog-styles/blog_element.php';
require_once get_template_directory() . '/cs-templates/blog-styles/blog_functions.php';
#Admin
require_once get_template_directory() . '/include/admin_functions.php';

//widgets
cs_require_theme_files( 'include/theme-components/cs-widgets/' );
require_once get_template_directory() . '/include/theme-components/cs-header/header_functions.php';

//googlefonts
require_once trailingslashit( get_template_directory() ) . 'include/theme-components/cs-googlefont/fonts.php';
require_once trailingslashit( get_template_directory() ) . 'include/theme-components/cs-googlefont/google_fonts.php';
require_once trailingslashit( get_template_directory() ) . 'include/theme-components/cs-googlefont/fonts_array.php';

//theme options
require_once trailingslashit( get_template_directory() ) . 'include/theme-options/theme_options.php';
require_once trailingslashit( get_template_directory() ) . 'include/theme-options/theme_options_fields.php';
require_once trailingslashit( get_template_directory() ) . 'include/theme-options/theme_options_functions.php';
require_once trailingslashit( get_template_directory() ) . 'include/theme-options/theme_options_arrays.php';

add_action('admin_menu', 'cs_theme_opt_menu');
function cs_theme_opt_menu() {
	add_theme_page( 'CS Theme Option', esc_html__( 'CS Theme Option', 'logistic' ), 'read', 'cs_options_page', 'cs_options_page' );
}

function cs_custom_enqueue_script( $custom_sh = 'custom-shortcode', $cs_widget = '' ) {
	global $post;
	
	$cs_enqueue = false;
	if( $custom_sh != '' && is_a( $post, 'WP_Post' ) ) {
		
		if( has_shortcode( $post->post_content, $custom_sh ) ) {
		
			$cs_enqueue = true;
		}
		
		$cs_post_meta = get_post_meta( $post->ID, 'cs_full_data', true );
		
		if( is_array( $cs_post_meta ) && has_shortcode( maybe_serialize( $cs_post_meta ), $custom_sh ) ) {
			
			$cs_enqueue = true;
		}
		
		$cs_page_meta = get_post_meta( $post->ID, 'cs_page_builder', true );
		
		if( $cs_page_meta != '' ) {
			
			$cs_page_meta = esc_html( $cs_page_meta );
			
			if( has_shortcode( $cs_page_meta, $custom_sh ) ) {
					
				$cs_enqueue = true;
			}
		}
	}
	
	if( $cs_widget != '' && is_active_widget( false, false, $cs_widget, true ) ) {
		
		$cs_enqueue = true;
	}
	
	return $cs_enqueue;
}

// Enqueue frontend style and scripts
if (!function_exists('cs_front_scripts_enqueue')) {
    function cs_front_scripts_enqueue() {
        global $cs_theme_options, $cs_enqueue_list;
        if (!is_admin()) {
			
			wp_enqueue_script(
				'bootstrap_min_script', 
				get_template_directory_uri() . '/assets/scripts/bootstrap.min.js', 
				array( 'jquery' ),
				'', 
				true
			);
			wp_enqueue_style('bootstrap_css_bootstrap_min', get_template_directory_uri() . '/assets/css/bootstrap.min.css');
			wp_enqueue_style('bootstrap_theme_css', get_template_directory_uri() . '/assets/css/bootstrap-theme.css');
			wp_enqueue_style('iconmoon_css', get_template_directory_uri() . '/assets/css/iconmoon.css');
			wp_enqueue_style('menu_css', get_template_directory_uri() . '/assets/css/menu.css');
			
			
			wp_enqueue_style('slick_css', get_template_directory_uri() . '/assets/css/slick.css');
			wp_enqueue_style('widget_css', get_template_directory_uri() . '/assets/css/widget.css');
			wp_enqueue_style('style_css', get_stylesheet_directory_uri() . '/style.css');
			wp_enqueue_style('browser_widget', get_template_directory_uri() . '/assets/css/browser-detect.css');
			
			if (isset($cs_theme_options['cs_responsive']) && $cs_theme_options['cs_responsive'] == "on") {
				echo '<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0">';
				wp_enqueue_style('responsive_css', get_template_directory_uri() . '/assets/css/responsive.css');
			}
			
			if (isset($cs_theme_options['cs_style_rtl']) and $cs_theme_options['cs_style_rtl'] == "on") {
				wp_enqueue_style('rtl_css', get_template_directory_uri() . '/assets/css/rtl.css');
			}
			
			wp_enqueue_style('prettyPhoto_css', get_template_directory_uri() . '/assets/css/prettyPhoto.css');
			wp_enqueue_script('prettyPhoto_js', get_template_directory_uri() . '/assets/scripts/jquery.prettyPhoto.js', '', '', true);
			
			// Theme Styles
			wp_enqueue_style('theme_style_css', get_template_directory_uri() . '/include/theme_styles.php');
			
			wp_enqueue_script('modernizr_min_js_file', get_template_directory_uri() . '/assets/scripts/modernizr.min.js', '', '', true);
			wp_enqueue_script('menu_js', get_template_directory_uri() . '/assets/scripts/menu.js', '', '', true);
			wp_enqueue_script('browser-detect', get_template_directory_uri() . '/assets/scripts/browser-detect.js', '', '', true);
			
			if (isset($cs_theme_options['cs_sitcky_header_switch']) and $cs_theme_options['cs_sitcky_header_switch'] == "on") {
				wp_enqueue_script('sticky_header_js', get_template_directory_uri() . '/assets/scripts/sticky_header.js', '', '', true);
			}
			wp_enqueue_script('isotope_js', get_template_directory_uri() . '/assets/scripts/isotope.min.js', '', '', true);
			
			if( cs_custom_enqueue_script( 'cs_quick_quote' ) ) {
				wp_enqueue_script('bootstrap_datepicker_js', get_template_directory_uri() . '/assets/scripts/bootstrap-datepicker.js', '', '', true);
			}
			
			if( cs_custom_enqueue_script( '', 'cs_twitter_widget' ) ) {
				wp_enqueue_script('slick_min', get_template_directory_uri() . '/assets/scripts/slick.min.js', '', '', true);
			}
			
			wp_enqueue_script('cs_addthis', 'http://s7.addthis.com/js/250/addthis_widget.js#pubid=xa-4e4412d954dccc64', '', '', true);
			
			if( cs_custom_enqueue_script( 'cs_multi_counters' ) ) {
				wp_enqueue_script('cs_counter_script', get_template_directory_uri() . '/assets/scripts/counter.js', '', '', true);
			}
			
			wp_enqueue_script('jquery.googleapis_js', 'http://maps.googleapis.com/maps/api/js?sensor=false&libraries=places', '', '', true);
			wp_enqueue_script('jquery.gmaps-latlon-picker_js', get_template_directory_uri() . '/include/assets/scripts/jquery_gmaps_latlon_picker.js', '', '', true);
			
			wp_enqueue_script('cs_functions_js', get_template_directory_uri() . '/assets/scripts/functions.js', '', '', true);
		}
    }
}

// Favicon and header code in head tag//
if (!function_exists('cs_header_settings')) {
    function cs_header_settings() {
        global $cs_theme_options;
		if ( ! function_exists( 'has_site_icon' ) || ! wp_site_icon() ) {
			$cs_favicon = isset($cs_theme_options['cs_custom_favicon']) ? $cs_theme_options['cs_custom_favicon'] : '';
			if($cs_favicon <> '') {
				?>
				<link rel="shortcut icon" href="<?php echo esc_url($cs_favicon); ?>">
				<?php
			}
		}
	}
}

// Favicon and header code in head tag
if ( ! function_exists('cs_footer_settings') ) {
    function cs_footer_settings() {
        global $cs_theme_options;
        ?>
        <!--[if lt IE 9]><link rel="stylesheet" href="<?php echo get_template_directory_uri(); ?>/css/ie8.css" /><![endif]-->
        <?php
        if (isset($cs_theme_options['analytics'])) {
            echo htmlspecialchars_decode($cs_theme_options['cs_custom_js']);
        }
    }
}
// password protect post/page
if (!function_exists('cs_password_form')) {
    function cs_password_form() {
        global $post, $cs_theme_option;
        $label = 'pwbox-' . ( empty($post->ID) ? rand() : $post->ID );
        $o = '<div class="password_protected">
                <div class="protected-icon"><a href="#"><i class="icon-unlock-alt icon-4x"></i></a></div>
                <h3>' . esc_html__("This post is password protected. To view it please enter your password below:", 'logistic') . '</h3>';
        $o .= '<form action="' . esc_url(home_url('wp-login.php?action=postpass', 'login_post')) . '" method="post"><label><input name="post_password" id="' . $label . '" type="password" size="20" /></label><input class="bgcolr" type="submit" name="Submit" value="' . esc_html__("Submit", 'logistic') . '" /></form>
            </div>';
        return $o;
    }
}
// add menu id
if (!function_exists('cs_add_menuid')) {
    function cs_add_menuid($ulid) {
        return preg_replace('/<ul>/', '<ul id="menus">', $ulid, 1);
    }
}
// remove additional div from menu
if (!function_exists('cs_remove_div')) {
    function cs_remove_div($menu) {
        return preg_replace(array('#^<div[^>]*>#', '#</div>$#'), '', $menu);
    }
}
// add parent class
if (!function_exists('cs_add_parent_css')) {
    function cs_add_parent_css($classes, $item) {
        global $cs_menu_children;
        if ($cs_menu_children)
            $classes[] = 'parent';
        return $classes;
    }
}
// change the default query variable start
if (!function_exists('cs_change_query_vars')) {
    function cs_change_query_vars($query) {
        if (is_search() || is_home()) {
            if (empty($_GET['page_id_all']))
                $_GET['page_id_all'] = 1;
            $query->query_vars['paged'] = $_GET['page_id_all'];
            return $query;
        }
    }

}
// Filter shortcode in text areas

if (!function_exists('cs_textarea_filter')) {
    function cs_textarea_filter($content = '') {
        return do_shortcode($content);
    }
}
//    Add Featured/sticky text/icon for sticky posts.
if (!function_exists('cs_featured')) {
    function cs_featured() {
        if (is_sticky()) {
            ?>
            <span class="featured-post"><?php esc_html_e('Featured', 'logistic'); ?></span>
            <?php
        }
    }
} 
// display post page title
if (!function_exists('cs_post_page_title')) {
    function cs_post_page_title() {
        if (is_author()) {
            global $author;
            $userdata = get_userdata($author);
            if (isset($_GET['action']) && $_GET['action'] == 'detail') {
                echo cs_allow_special_char($userdata->display_name);
            } else {
                echo esc_html__('Author', 'logistic') . " " . esc_html__('Archives', 'logistic') . ": " . $userdata->display_name;
            }
        } elseif (is_tag() || is_tax('event-tag')) {
            echo esc_html__('Tags', 'logistic') . " " . esc_html__('Archives', 'logistic') . ": " . single_cat_title('', false);
        } elseif (is_search()) {
            printf(esc_html__('Search Results : %s', 'logistic'), '<span>' . get_search_query() . '</span>');
        } elseif (is_day()) {
            printf(esc_html__('Daily Archives: %s', 'logistic'), '<span>' . get_the_date() . '</span>');
        } elseif (is_month()) {
            printf(esc_html__('Monthly Archives: %s', 'logistic'), '<span>' . get_the_date(_x('F Y', 'monthly archives date format', 'logistic')) . '</span>');
        } elseif (is_year()) {
            printf(esc_html__('Yearly Archives: %s', 'logistic'), '<span>' . get_the_date(_x('Y', 'yearly archives date format', 'logistic')) . '</span>');
        } elseif (is_404()) {
            esc_html_e('Error 404', 'logistic');
        } elseif (is_home()) {
            esc_html_e('Home', 'logistic');
        } elseif (!is_page()) {
            esc_html_e('Archives', 'logistic');
        }
    }

}
// If no content, include the "No posts found" function
if (!function_exists('cs_fnc_no_result_found')) {
    function cs_fnc_no_result_found() {
        $is_search = '';
        global $cs_theme_options;
        ?>
        <div class="page_detail">
            <div class="title">
            	<h2><?php esc_html_e('No pages were found containing','logistic');?> "<?php echo esc_attr(get_search_query());?>" </h2>
            </div>
        	<span><?php esc_html_e('Suggestions:', 'logistic'); ?></span>
            <ul>
                <li><?php esc_html_e('Make sure that all words are spelled correctly:', 'logistic'); ?></li>
                <li><?php esc_html_e('Try different keywords.:', 'logistic'); ?></li>
                <li><?php esc_html_e('Try more general keywords:', 'logistic'); ?></li>
            </ul>
            <form method="get" action="<?php echo esc_url(home_url('/')); ?>" >
            <input type="text" name="s"  class="text" value="" placeholder="Enter words for search">
            <input type="submit" class="submit cs-bgcolor" value="<?php esc_html_e('Search', 'logistic'); ?>">
            </form>
        </div> 
         <?php
    }
}

// Highlight Search Results
function cs_wps_highlight_results($text) {
    if (is_search()) {
        $sr = get_query_var('s');
        $keys = explode(" ", $sr);
        $text = preg_replace('/(' . implode('|', $keys) . ')/iu', '' . $sr . '', $text);
    }
    return $text;
}
add_filter('get_the_excerpt', 'cs_wps_highlight_results');
// Custom function for next previous posts
if (!function_exists('cs_next_prev_custom_links')) {
    function cs_next_prev_custom_links($post_type = 'events') {
        global $post, $wpdb, $cs_theme_options, $cs_xmlObject;
        $previd = $nextid = '';
        $post_type = get_post_type($post->ID);
        $count_posts = wp_count_posts("$post_type")->publish;
        $cs_postlist_args = array(
            'posts_per_page' => -1,
            'order' => 'ASC',
            'post_type' => "$post_type",
        );
        $cs_postlist = get_posts($cs_postlist_args);
        $ids = array();
        foreach ($cs_postlist as $cs_thepost) {
            $ids[] = $cs_thepost->ID;
        }
        $thisindex = array_search($post->ID, $ids);
        if (isset($ids[$thisindex - 1])) {
            $previd = $ids[$thisindex - 1];
        }
        if (isset($ids[$thisindex + 1])) {
            $nextid = $ids[$thisindex + 1];
        }
		 echo '<div class="pager-detail">';
			if (isset($nextid) && !empty($nextid) && $nextid >= 0) {
				?>
				<a href="<?php echo esc_url(get_permalink($nextid)) ?>" ><i class="icon-arrow-left10"></i></a>
				<?php
			}
			if (isset($previd) && !empty($previd)) {
				?>
				<a href="<?php echo esc_url(get_permalink($previd)) ?>" > <i class="icon-arrow-right10"></i></a>
				<?php
			}
        echo '</div>';
    }
}
 if (!function_exists('cs_related_post')) {
    function cs_related_post( $cs_col = false, $cs_limit = '-1' ) {
	    
		global $post;	  
	 	$title_limit = 10;
		$custom_taxterms = '';
		$width  = 250;
		$height = 188;		
 		$custom_taxterms = wp_get_object_terms( $post->ID, array('category'), array('fields' => 'ids') );
		$args = array(
					'post_type' => 'post',
					'post_status' => 'publish',
					'posts_per_page' => $cs_limit,
					'orderby' => 'DESC',
					'tax_query' => array(
					'relation' => 'OR',
						array(
						  'taxonomy' => 'category',
						  'field' => 'id',
						  'terms' => $custom_taxterms
						)
					),
					'post__not_in' => array ($post->ID),
				); 
		 $custom_query = new WP_Query($args);
		if($custom_query->post_count > 0){
		?>
        
		<div class="related-post ">
			<div class="detail-title">
            	<h3><span> <?php echo esc_html_e('Related Posts','logistic'); ?></span></h3>
            </div>
            
        <div class="cs-blog blog-medium">
		<?php		
		while ($custom_query->have_posts()) : $custom_query->the_post();
		?>
	        <article>
                <div class="cs-text"> 
                <span class="view-post">
                <?php $coments = get_comments_number(esc_html__('0', 'logistic'), esc_html__('1', 'logistic'), esc_html__('%', 'logistic'));
                	printf('%s', $coments);
                ?>
                </span>
                <div class="blog-title">
                <h3><a href="<?php esc_url(the_permalink()); ?>"><?php echo wp_trim_words(get_the_title($post->ID), $title_limit, '...'); ?></a></h3>
                </div>
                <span class="post-date"><?php echo get_the_author();?>- <?php echo date_i18n('M d , Y', strtotime(get_the_date())); ?></span>
                 
                </div>
            </article>
			<?php
		endwhile;
		?>
	</div>
   </div>
  
	<?php 
 	}	
  }
}
if (!function_exists('cs_portfolios_next_prev')) {
    function cs_portfolios_next_prev($post_type = 'portfolios') {
        global $post, $wpdb, $cs_theme_options;
        $previd = $nextid = '';
        $post_type = get_post_type($post->ID);
        $count_posts = wp_count_posts("$post_type")->publish;
        $cs_postlist_args = array(
            'posts_per_page' => -1,
            'order' => 'ASC',
            'post_type' => "$post_type",
        );
        $cs_postlist = get_posts($cs_postlist_args);
        $ids = array();
        foreach ($cs_postlist as $cs_thepost) {
            $ids[] = $cs_thepost->ID;
        }
        $thisindex = array_search($post->ID, $ids);
        if (isset($ids[$thisindex - 1])) {
            $previd = $ids[$thisindex - 1];
        }
        if (isset($ids[$thisindex + 1])) {
            $nextid = $ids[$thisindex + 1];
        }
        echo '<div class="cs-project-pagination"><ul>';
        if (isset($previd) && !empty($previd) && $previd >= 0) {
            ?>
            <li class="prev"><a href="<?php echo esc_url(get_permalink($previd)); ?>"><?php esc_html_e('Previous Project', 'logistic') ?></a></li>
            <?php
        }
        if ($previd > 0 || $nextid > 0) {
			
			$cs_prev_link = isset($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER'] : home_url('/');
            echo '<li class="back"><a href="' . esc_url($cs_prev_link) . '"><i class="icon-list8"></i> ' . esc_html__('Go Back', 'logistic') . '</a></li>';
        }
        if (isset($nextid) && !empty($nextid)) {
            ?>
            <li class="next"><a href="<?php echo esc_url(get_permalink($nextid)); ?>"><?php esc_html_e('Next Project', 'logistic') ?></a></li>
            <?php
        }
        echo '</ul></div>';
    }
}
/*    Function to get the events info on calander -- START    */

// register theme menu
function cs_register_my_menus() {
    register_nav_menus(
            array(
			
			    'top-menu' => esc_html__('Top Menu', 'logistic'),
                'main-menu' => esc_html__('Main Menu', 'logistic')
				
                
            )
    );
}

add_action('init', 'cs_register_my_menus');

//  Set Post Veiws Start
//  Excerpt Default Length 
function cs_custom_excerpt_length($length) {
    return 200;
}

add_filter('excerpt_length', 'cs_custom_excerpt_length');
// Custom excerpt function 
if (!function_exists('cs_get_the_excerpt')) {

    function cs_get_the_excerpt($charlength = '255', $readmore = 'true', $readmore_text = 'Read More') {
        global $post, $cs_theme_option;
        $excerpt = trim(preg_replace('/<a[^>]*>(.*)<\/a>/iU', '', get_the_excerpt()));
		
 if (strlen($excerpt) > $charlength) {
            if ($charlength > 0) {
				
                $excerpt = substr($excerpt, 0, $charlength);
				
            } else {
                $excerpt = $excerpt;
            }
            if ($readmore == 'true') {
                $more = '..';
            } else {
                $more = '...';
            }
            return $excerpt . $more;
        } else {
            return $excerpt;
        }
    }

}


/* Excerpt Read More  */

function cs_excerpt_more($more = '...') {
    return '....';
}

add_filter('excerpt_more', 'cs_excerpt_more');

function cs_remove_menu_ids() {
    add_filter('nav_menu_item_id', '__return_null');
}

add_action('init', 'cs_remove_menu_ids');

// Return Seleced
if (!function_exists('cs_selected')) {

    function cs_selected($current, $orignal) {
        if ($current == $orignal) {
            echo 'selected=selected';
        }
    }

}

if ( ! function_exists('cs_allow_special_char') ) {
	function cs_allow_special_char($input = '') {
		$output  = $input;
		return $output;
	}
}

// get shortcode content
if (!function_exists('cs_content_render')) {
    function cs_content_render($atts, $content = ""){
        global $post;
        ob_start();
         the_content();
         wp_link_pages( array( 'before' => '<div class="page-links"><span class="page-links-title">' . __( 'Pages:', 'logistic' ) . '</span>', 'after' => '</div>', 'link_before' => '<span>', 'link_after' => '</span>' ) );
        $content_data = ob_get_clean();
        return $content_data;
    }
    if (function_exists('cs_short_code')) cs_short_code('cs_content', 'cs_content_render');
}
 
// page builder element size
if (!function_exists('cs_pb_element_sizes')) {

    function cs_pb_element_sizes($size = '100') {

        if ( isset($size) && $size == '' ) {
            $element_size = 'element-size-100';
        } else {
            $element_size_col = $size;
        }
		
        if (isset($element_size_col) and $element_size_col == '100' || $element_size_col > 75) {

            $element_size = 'col-lg-12';
        } else if (isset($element_size_col) and $element_size_col == '75' || $element_size_col > 67) {

            $element_size = 'col-lg-9';
        } else if (isset($element_size_col) and $element_size_col == '67' || $element_size_col > 50) {

            $element_size = 'col-lg-8';
        } else if (isset($element_size_col) and $element_size_col == '50' || $element_size_col > 33) {

            $element_size = 'col-lg-6';
        } else if (isset($element_size_col) and $element_size_col == '33' || $element_size_col > 25) {

            $element_size = 'col-lg-4';
        } else if (isset($element_size_col) and $element_size_col == '25' || $element_size_col < 25) {

            $element_size = 'col-lg-3';
        }
		
        return $element_size;
    }

}
if (!function_exists('cs_enable_more_buttons')) {

    function cs_enable_more_buttons($buttons) {

        $buttons[] = 'fontselect';
        $buttons[] = 'fontsizeselect';
        $buttons[] = 'styleselect';
        $buttons[] = 'backcolor';
        $buttons[] = 'newdocument';
        $buttons[] = 'cut';
        $buttons[] = 'copy';
        $buttons[] = 'charmap';
        $buttons[] = 'hr';
        $buttons[] = 'visualaid';
        return $buttons;
    }

    add_filter("mce_buttons_3", "cs_enable_more_buttons");
}
add_action('init', 'cs_deregister_heartbeat', 1);

function cs_deregister_heartbeat() {
    global $pagenow;
    if ('post.php' != $pagenow && 'post-new.php' != $pagenow)
        wp_deregister_script('heartbeat');
}

// Like Counter
if (!function_exists('cs_like_counter')) {

    function cs_like_counter($cs_likes_title = '') {
        $cs_like_counter = '';
        $cs_like_counter = get_post_meta(get_the_id(), "cs_like_counter", true);
        if (!isset($cs_like_counter) or empty($cs_like_counter))
            $cs_like_counter = 0;
        if (isset($_COOKIE["cs_like_counter" . get_the_id()])) {
            ?>
            <a> <i class="icon-heart liked-post"></i><span><?php echo cs_allow_special_char($cs_like_counter . ' ' . $cs_likes_title); ?></span></a> 
        <?php } else { ?>
            <a class="likethis<?php echo get_the_id() ?> cs-btnheart cs-btnpopover" id="like_this<?php echo get_the_id() ?>"  href="javascript:cs_like_counter('<?php echo esc_url(get_template_directory_uri()); ?>',<?php echo get_the_id() ?>,'<?php echo cs_allow_special_char($cs_likes_title); ?>','<?php echo admin_url('admin-ajax.php'); ?>')" data-container="body" data-toggle="tooltip" data-placement="top" title="<?php esc_html_e('Like This', 'logistic'); ?>"><i class="icon-heart-o"></i><span><?php echo cs_allow_special_char($cs_like_counter . ' ' . $cs_likes_title); ?></span></a>

            <a class="likes likethis" id="you_liked<?php echo get_the_id() ?>" style="display:none;"><i class="icon-heart  liked-post"></i><span class="count-numbers like_counter<?php echo get_the_id() ?>"><?php echo cs_allow_special_char($cs_like_counter . ' ' . $cs_likes_title); ?></span> </a>

            <div id="loading_div<?php echo get_the_id() ?>" style="display:none;"><i class="icon-spinner icon-spin"></i></div>
        <?php
        }
    }

    //likes counter
    add_action('wp_ajax_nopriv_cs_likes_count', 'cs_likes_count');
    add_action('wp_ajax_cs_likes_count', 'cs_likes_count');
}
// Post like counter
if (!function_exists('cs_likes_count')) {

    function cs_likes_count() {
        $cs_like_counter = get_post_meta($_POST['post_id'], "cs_like_counter", true);
        if (!isset($_COOKIE["cs_like_counter" . $_POST['post_id']])) {
            setcookie("cs_like_counter" . $_POST['post_id'], 'true', time() + (10 * 365 * 24 * 60 * 60), '/');
            update_post_meta($_POST['post_id'], 'cs_like_counter', $cs_like_counter + 1);
        }
        $cs_like_counter = get_post_meta($_POST['post_id'], "cs_like_counter", true);
        if (!isset($cs_like_counter) or empty($cs_like_counter))
            $cs_like_counter = 0;
        echo cs_allow_special_char($cs_like_counter);
        die();
    }

}

/**
 * Add TinyMCE to multiple Textareas (usually in backend).
 */
function cs_wp_editor($id = '') {
    ?>
    <script type="text/javascript">
        var fullId = "<?php echo cs_allow_special_char($id); ?>";
        //tinymce.execCommand('mceAddEditor', false, fullId);
        // use wordpress settings
        tinymce.init({
            selector: fullId,
            theme: "modern",
            skin: "lightgray",
            language: "en",
            selector:"#" + fullId,
                    resize: "vertical",
            menubar: false,
            wpautop: true,
            indent: false,
            quicktags: "em,strong,link",
            toolbar1: "bold,italic,strikethrough,bullist,numlist,blockquote,hr,alignleft,aligncenter,alignright,link,unlink",
            //toolbar2:"formatselect,underline,alignjustify,forecolor,pastetext,removeformat,charmap,outdent,indent,undo,redo,wp_help",
            tabfocus_elements: ":prev,:next",
            body_class: "id post-type-post post-status-publish post-format-standard",
        });
        //quicktags({id : fullId});
        settings = {
            id: fullId,
            // buttons: 'strong,em,link' 
        }
        quicktags(settings);
           </script>
		   <?php
}

add_action('wp_ajax_cs_select_editor', 'cs_wp_editor');
//Submit Form
add_action('wp_ajax_nopriv_cs_contact_form_submit', 'cs_contact_form_submit');
add_action('wp_ajax_cs_contact_form_submit', 'cs_contact_form_submit');

//Get attachment id
function cs_get_attachment_id_from_url($attachment_url = '') {
    global $wpdb;
    $attachment_id = false;
    // If there is no url, return.
    if ('' == $attachment_url)
        return;

    // Get the upload directory paths
    $upload_dir_paths = wp_upload_dir();

    if (false !== strpos($attachment_url, $upload_dir_paths['baseurl'])) {

        // If this is the URL of an auto-generated thumbnail, get the URL of the original image
        $attachment_url = preg_replace('/-\d+x\d+(?=\.(jpg|jpeg|png|gif)$)/i', '', $attachment_url);

        // Remove the upload path base directory from the attachment URL
        $attachment_url = str_replace($upload_dir_paths['baseurl'] . '/', '', $attachment_url);

        $attachment_id = $wpdb->get_var($wpdb->prepare("SELECT wposts.ID FROM $wpdb->posts wposts, $wpdb->postmeta wpostmeta WHERE wposts.ID = wpostmeta.post_id AND wpostmeta.meta_key = '_wp_attached_file' AND wpostmeta.meta_value = '%s' AND wposts.post_type = 'attachment'", $attachment_url));
    }
    return $attachment_id;
}

// Custom File types allowed
add_filter('upload_mimes', 'cs_custom_upload_mimes');

function cs_custom_upload_mimes($existing_mimes = array()) {
    // add the file extension to the array
    $existing_mimes['woff'] = 'mime/type';
    $existing_mimes['ttf'] = 'mime/type';
    $existing_mimes['svg'] = 'mime/type';
    $existing_mimes['eot'] = 'mime/type';
    return $existing_mimes;
}

// Contact form submit ajax
function cs_contact_form_submit() {
    define('WP_USE_THEMES', false);
    $subject = '';
    $cs_contact_error_msg = '';
    $subject_name = 'Subject';
    foreach ($_REQUEST as $keys => $values) {
        $$keys = $values;
    }

    $bloginfo = get_bloginfo();
    $subjecteEmail = "(" . $bloginfo . ") Contact Form Received";
    $message = '
            <table width="100%" border="1">
              <tr>
                <td width="100"><strong>' . esc_html__('Name:', 'logistic') . '</strong></td>
                <td>' . $contact_name . '</td>
              </tr>
              <tr>
                <td><strong>' . esc_html__('Email:', 'logistic') . '</strong></td>
                <td>' . $contact_email . '</td>
              </tr>
              <tr>
                <td><strong>' . esc_html__('Phone:', 'logistic') . ':</strong></td>
                <td>' . $phone_no . '</td>
              </tr>
			  <tr>
                <td><strong>' . esc_html__('Message:', 'logistic') . '</strong></td>
                <td>' . $contact_msg . '</td>
              </tr>
              <tr>
                <td><strong>'.esc_html__('IP Address', 'logistic').'</strong></td>
                <td>' . $_SERVER["REMOTE_ADDR"] . '</td>
              </tr>
            </table>';

    $headers = "From: " . $contact_name . "\r\n";
    $headers .= "Reply-To: " . $contact_email . "\r\n";
    $headers .= "Content-type: text/html; charset=utf-8" . "\r\n";
    $headers .= "MIME-Version: 1.0" . "\r\n";
    $attachments = '';

    if (wp_mail(sanitize_email(get_bloginfo('admin_email')), sanitize_email($subjecteEmail), $message, $headers, $attachments)) {
        $json = array();
        $json['type'] = "success";
        $json['message'] = '<p>' . cs_textarea_filter($cs_contact_succ_msg) . '</p>';
    } else {
        $json['type'] = "error";
        $json['message'] = '<p>' . cs_textarea_filter($cs_contact_error_msg) . '</p>';
    };

    echo json_encode($json);
    die();
}

add_action('wp_ajax_nopriv_cs_quote_form_submit', 'cs_quote_form_submit');
add_action('wp_ajax_cs_quote_form_submit', 'cs_quote_form_submit');

function cs_quote_form_submit() {
    define('WP_USE_THEMES', false);

    $cs_quote_error_msg = '';
    foreach ($_REQUEST as $keys => $values) {
        $$keys = $values;
    }
	
    $bloginfo = get_bloginfo();
    $subjecteEmail = "(" . $bloginfo . ") Quote Form Received";
    $message = '
            <table width="100%" border="1">
              <tr>
                <td width="100"><strong>' . esc_html__('Name:', 'logistic') . '</strong></td>
                <td>' . $quote_name . '</td>
              </tr>
              <tr>
                <td><strong>' . esc_html__('Email:', 'logistic') . '</strong></td>
                <td>' . $quote_mail . '</td>
              </tr>
             
			  <tr>
                <td><strong>' . esc_html__('Date:', 'logistic') . '</strong></td>
                <td>' . $quote_date . '</td>
              </tr>
			 
                <td><strong>' . esc_html__('Service:', 'logistic') . '</strong></td>
                <td>' . $quote_service . '</td>
              </tr>
			  <tr>
                <td><strong>' . esc_html__('Message:', 'logistic') . '</strong></td>
                <td>' . $quote_message . '</td>
              </tr>
              <tr>
                <td><strong>' . esc_html__('IP Address:', 'logistic') . '</strong></td>
                <td>' . $_SERVER["REMOTE_ADDR"] . '</td>
              </tr>
            </table>';

    $headers = "From: " . $quote_name . "\r\n";
    $headers .= "Reply-To: " . $quote_mail . "\r\n";
    $headers .= "Content-type: text/html; charset=utf-8" . "\r\n";
    $headers .= "MIME-Version: 1.0" . "\r\n";
    $attachments = '';

    if (wp_mail(sanitize_email($cs_quote_email), sanitize_email($subjecteEmail), $message, $headers, $attachments)) {
        $json = array();
        $json['type'] = "success";
        $json['message'] = '<p>' . cs_textarea_filter($cs_quote_succ_msg) . '</p>';
    } else {
        $json['type'] = "error";
        $json['message'] = '<p>' . cs_textarea_filter($cs_quote_error_msg) . '</p>';
    };

    echo json_encode($json);
    die();
}

 /* RevSlider Extend Class 
 */
if (class_exists('RevSlider')) {

    class cs_RevSlider extends RevSlider {

        // Get sliders alias, Title, ID
        public function getAllSliderAliases() {
            $where = "";
            $response = $this->db->fetch(GlobalsRevSlider::$table_sliders, $where, "id");
            $arrAliases = array();
            $slider_array = array();
            foreach ($response as $arrSlider) {
                $arrAliases['id'] = $arrSlider["id"];
                $arrAliases['title'] = $arrSlider["title"];
                $arrAliases['alias'] = $arrSlider["alias"];
                $slider_array[] = $arrAliases;
            }
            return($slider_array);
        }

    }

}


if (!function_exists('cs_custom_widget_title')) {

    function cs_custom_widget_title($title) {
        $title = $title;
        return $title;
    }

}
add_filter('widget_title', 'cs_custom_widget_title');
// count Banner Clicks
if (!function_exists('cs_banner_click_count_plus')) {

    function cs_banner_click_count_plus() {
        $code_id = $_POST['code_id'];
        $cs_banner_click_count = get_option("cs_banner_clicks_" . $code_id);
        $cs_banner_click_count = $cs_banner_click_count <> '' ? $cs_banner_click_count : 0;
        if (!isset($_COOKIE["cs_banner_clicks_" . $code_id])) {
            setcookie("cs_banner_clicks_" . $code_id, 'true', time() + 86400, '/');
            update_option("cs_banner_clicks_" . $code_id, $cs_banner_click_count + 1);
        }
        die(0);
    }

    add_action('wp_ajax_cs_banner_click_count_plus', 'cs_banner_click_count_plus');
    add_action('wp_ajax_nopriv_cs_banner_click_count_plus', 'cs_banner_click_count_plus');
}

// custom pagination start
 if (!function_exists('cs_pagination')) {

    function cs_pagination($total_records, $per_page, $qrystr = '', $show_pagination = 'Show Pagination',$pagination_class='') {
        if ($show_pagination <> 'Show Pagination') {
            return;
        } else if ($total_records < $per_page) {
            return;
        } else {

            $html = '';

            $dot_pre = '';

            $dot_more = '';

            $total_page = 0;
            if ($per_page <> 0)
                $total_page = ceil($total_records / $per_page);
            $page_id_all = 0;
            if (isset($_GET['page_id_all']) && $_GET['page_id_all'] != '') {
                $page_id_all = $_GET['page_id_all'];
            }

            $loop_start = $page_id_all - 2;

            $loop_end = $page_id_all + 2;

            if ($page_id_all < 3) {

                $loop_start = 1;

                if ($total_page < 5)
                    $loop_end = $total_page;
                else
                    $loop_end = 5;
            }

            else if ($page_id_all >= $total_page - 1) {

                if ($total_page < 5)
                    $loop_start = 1;
                else
                    $loop_start = $total_page - 4;

                $loop_end = $total_page;
            }
            $html .= "<nav><ul class='pagination'>";
            if ($page_id_all > 1) {
               } else {
               }

            if ($page_id_all > 3 and $total_page > 5)
                $html .= "<li><a href='?page_id_all=1$qrystr'>1</a></li>";

            if ($page_id_all > 4 and $total_page > 6)
                $html .= "<li> <a>. . .</a> </li>";

            if ($total_page > 1) {

                for ($i = $loop_start; $i <= $loop_end; $i++) {

                    if ($i <> $page_id_all)
                        $html .= "<li><a href='?page_id_all=$i$qrystr'>" . $i . "</a></li>";
                    else
                        $html .= "<li><a class='active'>" . $i . "</a></li>";
                }
            }

            if ($loop_end <> $total_page and $loop_end <> $total_page - 1)
                $html .= "<li> <a>. . .</a> </li>";

            if ($loop_end <> $total_page)
                $html .= "<li><a href='?page_id_all=$total_page$qrystr'>$total_page</a></li>";
            if ($per_page > 0 and $page_id_all < $total_records / $per_page) {

                  } else {
              }
            $html .= "</ul></nav>";
            return $html;
        }
    }

}
// pagination end
// Social Share Function

if (!function_exists('cs_social_share_blog')) {

    function cs_social_share_blog($default_icon = 'false', $title = 'true', $post_social_sharing_text = '') {
        global $cs_theme_options;
        $html = '';
        $twitter = $cs_theme_options['cs_twitter_share'];
        $facebook = $cs_theme_options['cs_facebook_share'];
        $google_plus = $cs_theme_options['cs_google_plus_share'];
        $tumblr = $cs_theme_options['cs_tumblr_share'];
        $dribbble = $cs_theme_options['cs_dribbble_share'];
        $instagram = $cs_theme_options['cs_instagram_share'];
        $share = $cs_theme_options['cs_share_share'];
        $stumbleupon = $cs_theme_options['cs_stumbleupon_share'];
        $youtube = $cs_theme_options['cs_youtube_share'];
        $html = '';
		
		$path = get_template_directory_uri() . "/include/assets/images/";
        if ($twitter == 'on' or $facebook == 'on' or $google_plus == 'on'  or $tumblr == 'on' or $dribbble == 'on' or $instagram == 'on' or $share == 'on' or $stumbleupon == 'on' or $youtube == 'on') {
         
		 if(is_single()){ 
			 
			$html .='<ul class="social-media">';
			
				if (isset($facebook) && $facebook == 'on') {
					$html .='<li><a class="addthis_button_facebook"  data-original-title="facebook" ><i style="color:#305891;" class="icon-facebook7"></i></a></li>';
				}	 
				if (isset($twitter) && $twitter == 'on') {
					$html .='<li><a class="addthis_button_twitter"  data-original-title="twitter" ><i style="color:#2ca8d2;" class="icon-twitter6"></i></a></li>';
				}
				
				if (isset($google_plus) && $google_plus == 'on') {
					$html .='<li><a class="addthis_button_google" data-original-title="google"><i style="color:#D74633;" class="icon-googleplus7"></i></a></li>';
				}
				
				if (isset($tumblr) && $tumblr == 'on') {
					$html .='<li><a class="addthis_button_tumblr" style="color:#ff5422" data-original-title="tumblr"><i style="color:#33465D;" class="icon-tumblr5"></i></a></li>';
				}
				if (isset($dribbble) && $dribbble == 'on') {
					$html .='<li><a class="addthis_button_dribbble" style="color:#ff5422" data-original-title="dribbble"><i style="color:#000000;" class="icon-dribbble7"></i></a></li>';
				}
				if (isset($instagram) && $instagram == 'on') {
					$html .='<li><a class="addthis_button_instagram" style="color:#ff5422" data-original-title="Instagram"><i style="color:#E7DDD4;" class="icon-instagram"></i></a></li>';
				}
				  
				if (isset($stumbleupon) && $stumbleupon == 'on') {
					$html .='<li><a class="addthis_button_stumbleupon" style="color:#ff5422" data-original-title="stumbleupon"><i style="color:#CC4A2B;" class="icon-stumbleupon4"></i></a></li>';
				}
				
				if (isset($youtube) && $youtube == 'on') {
					$html .='<li><a class="addthis_button_youtube" style="color:#ff5422" data-original-title="youtube"><i style="color:#DC2825;" class="icon-youtube"></i></a></li>';
				}
				
				if (isset($share) && $share == 'on') {
					$html .='<li class="more"  style="color:#fff; background:#296079"><a style="color:#fff" class="cs-more addthis_button_compact" data-original-title="ellipsis"><i class="icon-ellipsis"></i></a></li>';
				}
				
			$html .='</ul>';
			
		}else{
		    
			 $html .='<span class="btn-share"><i class="icon-share-alt"></i>';
				 $html .='<ul class="share-with">';
					if (isset($facebook) && $facebook == 'on') {
						
						$html .='<li><a class="addthis_button_facebook"  data-original-title="facebook" ><i style="color:#305891;" class="icon-facebook7"></i></a></li>';
						
					}	 
					if (isset($twitter) && $twitter == 'on') {
						
						$html .='<li><a class="addthis_button_twitter"  data-original-title="twitter" ><i style="color:#2ca8d2;" class="icon-twitter6"></i></a></li>';
					}
					
					if (isset($google_plus) && $google_plus == 'on') {
						
						$html .='<li><a class="addthis_button_google" data-original-title="google"><i style="color:#D74633;" class="icon-googleplus7"></i></a></li>';
					}
					
					if (isset($tumblr) && $tumblr == 'on') {
						
						$html .='<li><a class="addthis_button_tumblr" style="color:#ff5422" data-original-title="tumblr"><i style="color:#33465D;" class="icon-tumblr5"></i></a></li>';
					}
					if (isset($dribbble) && $dribbble == 'on') {
						
						$html .='<li><a class="addthis_button_dribbble" style="color:#ff5422" data-original-title="dribbble"><i style="color:#000000;" class="icon-dribbble7"></i></a></li>';
					}
					if (isset($instagram) && $instagram == 'on') {
						
						$html .='<li><a class="addthis_button_instagram" style="color:#ff5422" data-original-title="Instagram"><i style="color:#E7DDD4;" class="icon-instagram"></i></a></li>';
					}
					if (isset($youtube) && $youtube == 'on') {
						
						$html .='<li><a class="addthis_button_youtube" style="color:#ff5422" data-original-title="youtube"><i style="color:#DC2825;" class="icon-youtube"></i></a></li>';
					}
					
					if (isset($stumbleupon) && $stumbleupon == 'on') {
						
						$html .='<li><a class="addthis_button_stumbleupon" style="color:#ff5422" data-original-title="stumbleupon"><i style="color:#CC4A2B;" class="icon-stumbleupon4"></i></a></li>';
					}
					
					if (isset($share) && $share == 'on') {
						
						$html .='<li class="more"  style="color:#fff; background:#296079"><a style="color:#fff" class="cs-more addthis_button_compact" data-original-title="ellipsis"><i class="icon-ellipsis"></i></a></li>';
					
					}
			 $html .='</ul>';
			 $html .='</span>';
			
			}
		}
		
        echo balanceTags($html, true);
    }

}

if (!function_exists('cs_portfolio_share')) {

    function cs_portfolio_share($post_social_sharing_text = '') {
        global $cs_theme_options;
        $html = '';
        $twitter = $cs_theme_options['cs_twitter_share'];
        $facebook = $cs_theme_options['cs_facebook_share'];
        $google_plus = $cs_theme_options['cs_google_plus_share'];
        $tumblr = $cs_theme_options['cs_tumblr_share'];
        $dribbble = $cs_theme_options['cs_dribbble_share'];
        $instagram = $cs_theme_options['cs_instagram_share'];
        $share = $cs_theme_options['cs_share_share'];
        $stumbleupon = $cs_theme_options['cs_stumbleupon_share'];
        $youtube = $cs_theme_options['cs_youtube_share'];
        $html = '';
        $path = get_template_directory_uri() . "/include/assets/images/";
        if ($twitter == 'on' or $facebook == 'on' or $google_plus == 'on' or $pinterest == 'on' or $tumblr == 'on' or $dribbble == 'on' or $instagram == 'on' or $share == 'on' or $stumbleupon == 'on' or $youtube == 'on') {
            $html = '';
            $html .='<span class="title">' . $post_social_sharing_text . '</span>';
            $html .='<ul>';
            if (isset($facebook) && $facebook == 'on') {
                $html .='<li><a class="addthis_button_facebook" data-original="facebook"><i class="icon-facebook9"></i></a></li>';
            }
            if (isset($twitter) && $twitter == 'on') {
                $html .='<li><a class="addthis_button_twitter" data-original="twitter"><i class="icon-twitter2"></i></a></li>';
            }
            if (isset($google_plus) && $google_plus == 'on') {
                $html .='<li><a class="addthis_button_google" data-original="googleplus"><i class="icon-google-plus"></i></a></li>';
            }
            if (isset($tumblr) && $tumblr == 'on') {
                $html .='<li><a class="addthis_button_tumblr" data-original="tumblr"><i class="icon-tumblr2"></i></a></li>';
            }
            if (isset($dribbble) && $dribbble == 'on') {
                $html .='<li><a class="addthis_button_dribbble" data-original="dribbble"><i class="icon-dribbble2"></i></a></li>';
            }
            if (isset($instagram) && $instagram == 'on') {
                $html .='<li><a class="addthis_button_instagram" data-original="instagram"><i class="icon-instagram"></i></a></li>';
            }
            if (isset($stumbleupon) && $stumbleupon == 'on') {
                $html .='<li><a class="addthis_button_stumbleupon" data-original="stumbleupon"><i class="icon-stumbleupon"></i></a></li>';
            }
            if (isset($youtube) && $youtube == 'on') {
                $html .='<li><a class="addthis_button_youtube" data-original="youtube"><i class="icon-youtube"></i></a></li>';
            }
			 $html .= '</ul>';
            $html .= '<a class="btn-share addthis_button_compact">' . esc_html__('Other Share Options', 'logistic') . '</a>';
        }
        echo balanceTags($html, true);
    }

}

// Social network

if (!function_exists('cs_social_network')) {

    function cs_social_network($icon_type = '', $tooltip = '') {
        global $cs_theme_options;
        $tooltip_data = '';
        if ($icon_type == 'large') {
            $icon = 'icon-2x';
        } else {

            $icon = '';
        }
        if (isset($tooltip) && $tooltip <> '') {
            $tooltip_data = 'data-placement-tooltip="tooltip"';
        }
        if (isset($cs_theme_options['social_net_url']) and count($cs_theme_options['social_net_url']) > 0) {
            $i = 0;
            foreach ($cs_theme_options['social_net_url'] as $val) {

                if ($val != '') {
                    ?>
                        <li>
                            <a  class="cs-color-hover" title="" href="<?php echo esc_url($val); ?>" 
                            <?php echo balanceTags($tooltip_data, false); ?>  target="_blank">
                            <?php if ($cs_theme_options['social_net_awesome'][$i] <> '' && isset($cs_theme_options['social_net_awesome'][$i])) { ?>
                            <i class="<?php echo esc_attr($cs_theme_options['social_net_awesome'][$i]); ?> <?php echo esc_attr($icon); ?>"></i>
                            
                            <?php } else { ?>
                            <img src="<?php echo esc_url($cs_theme_options['social_net_icon_path'][$i]); ?>" alt="<?php echo esc_attr($cs_theme_options['social_net_tooltip'][$i]); ?>" />
                            <?php } ?>
                            </a>
                        </li>
                   <?php
                }
                $i++;
            }
        }
    }

}

// social network links
if (!function_exists('cs_social_network_widget')) {

    function cs_social_network_widget($icon_type = '', $tooltip = '') {
        global $cs_theme_option;
        global $cs_theme_option;
        $tooltip_data = '';
        if ($icon_type == 'large') {
            $icon = 'icon-2x';
        } else {

            $icon = '';
        }
        if (isset($tooltip) && $tooltip <> '') {
            $tooltip_data = 'data-placement-tooltip="tooltip"';
        }
        if (isset($cs_theme_option['social_net_url']) and count($cs_theme_option['social_net_url']) > 0) {
            $i = 0;
            foreach ($cs_theme_option['social_net_url'] as $val) {
                ?>
                <?php if ($val != '') { ?>
                    <a class="cs-colrhvr" title="" href="<?php echo esc_url($val); ?>" data-original-title="<?php echo esc_attr($cs_theme_option['social_net_tooltip'][$i]); ?>" data-placement="top" <?php echo balanceTags($tooltip_data, false); ?> target="_blank">
                    <?php if ($cs_theme_option['social_net_awesome'][$i] <> '' && isset($cs_theme_option['social_net_awesome'][$i])) { ?> 

                            <i class="fa <?php echo esc_attr($cs_theme_option['social_net_awesome'][$i]); ?>"></i>
                    <?php } else { ?><img src="<?php echo esc_url($cs_theme_option['social_net_icon_path'][$i]); ?>" alt="<?php echo esc_attr($cs_theme_option['social_net_tooltip'][$i]); ?>" /><?php } ?>
                    </a>
                <?php
                }

                $i++;
            }
        }
    }

}


//footer subscription

if ( ! function_exists( 'cs_subscriber_custom_mailchimp' ) ) {
  function cs_subscriber_custom_mailchimp(){
			global $cs_theme_options,$counter;    
			if ( function_exists( 'cs_custom_mailchimp' ) ) { echo  cs_custom_mailchimp(); }
		           
	}
}




//Mailchimp
add_action('wp_ajax_nopriv_cs_mailchimp', 'cs_mailchimp');
add_action('wp_ajax_cs_mailchimp', 'cs_mailchimp');

function cs_mailchimp() {
    global $cs_theme_options, $counter;
	if( class_exists( 'MailChimp' ) ) {
		$mailchimp_key = '';
		if (isset($cs_theme_options['cs_mailchimp_key'])) {
		   $mailchimp_key = $cs_theme_options['cs_mailchimp_key'];
		}
		
		
		$email = $_POST['mc_email'];
	   if(isset($email) && $email <> "" ){
			
			if (isset($_POST) and ! empty($_POST['cs_list_id']) and $mailchimp_key != '') {
				if ($mailchimp_key <> '') {
					$MailChimp = new MailChimp($mailchimp_key);
				}
				
				$list_id = $_POST['cs_list_id'];
				$result = $MailChimp->call('lists/subscribe', array(
							'id' => $list_id,
							'email' => array('email' => $email),
							'merge_vars' => array(),
							'double_optin' => false,
							'update_existing' => false,
							'replace_interests' => false,
							'send_welcome' => true,
				));
				
				if ($result <> '') {
					if (isset($result['status']) and $result['status'] == 'error') {
						echo cs_allow_special_char($result['error']);
					} else {
						echo 'Subscribe successfully';
					}
				}
			} else {
				echo 'please set API key';
			}
	  }else{
		 echo 'Enter Email Address';   
	  }
	}
    die();
}


//Single files paths
function get_custom_post_type_template($single_template) {
    global $post;
    $single_path = get_template_directory();
    
    return $single_template;
}

add_filter('single_template', 'get_custom_post_type_template');

// Post image attachment function
if (!function_exists('cs_attachment_image_src')) {

    function cs_attachment_image_src($attachment_id, $width, $height) {
        $image_url = wp_get_attachment_image_src($attachment_id, array($width, $height), true);
        if ($image_url[1] == $width and $image_url[2] == $height)
            ;
        else
            $image_url = wp_get_attachment_image_src($attachment_id, "full", true);
        $parts = explode('/uploads/', $image_url[0]);
        if (count($parts) > 1)
            return $image_url[0];
    }

}
// Post image attachment source function
if (!function_exists('cs_get_post_img_src')) {

    function cs_get_post_img_src($post_id, $width, $height) {
        global $post;
        if (has_post_thumbnail()) {
            $image_id = get_post_thumbnail_id($post_id);
            $image_url = wp_get_attachment_image_src($image_id, array($width, $height), true);
            if ($image_url[1] == $width and $image_url[2] == $height) {
                return $image_url[0];
            } else {
                $image_url = wp_get_attachment_image_src($image_id, "full", true);
                return $image_url[0];
            }
        }
    }

}


// Post image attachment source function
if (!function_exists('cs_get_post_img_title')) {
    function cs_get_post_img_title($post_id) {
        global $post;
        if (has_post_thumbnail()) {
            $image_id = get_post_thumbnail_id($post_id);
            $image_title = get_the_title( $image_id );
            if (isset($image_title) and $image_title  <>'') {
                return $image_title;
            } else {
                 return '';
            }
        }
    }

}

// Get Post image attachment
if (!function_exists('cs_get_post_img')) {

    function cs_get_post_img($post_id, $width, $height) {
        $image_id = get_post_thumbnail_id($post_id);
        $image_url = wp_get_attachment_image_src($image_id, array($width, $height), true);
        if ($image_url[1] == $width and $image_url[2] == $height) {
            return get_the_post_thumbnail($post_id, array($width, $height));
        } else {
            return get_the_post_thumbnail($post_id, "full");
        }
    }

}
// Get Main background
if (!function_exists('cs_bg_image')) {

    function cs_bg_image() {

        global $cs_theme_options;
		$cs_custom_bgimage = isset($cs_theme_options['cs_custom_bgimage']) ? $cs_theme_options['cs_custom_bgimage']  : '';
		//var_dump($cs_custom_bgimage);
        $cs_bg_image = '';
        if ($cs_custom_bgimage == "") {
            if (isset($cs_theme_options['cs_bg_image']) && $cs_theme_options['cs_bg_image'] <> '' and $cs_theme_options['cs_bg_image'] <> 'bg0' and $cs_theme_options['cs_bg_image'] <> 'pattern0') {
                $cs_bg_image = get_template_directory_uri() . "/include/assets/images/background/" . $cs_theme_options['cs_bg_image'] . ".png";
            }
        } elseif ($cs_custom_bgimage <> 'pattern0') {
            $cs_bg_image = $cs_theme_options['cs_custom_bgimage'];
        }
        if ($cs_bg_image <> "") {
            return ' style="background:url(' . $cs_bg_image . ') ' . $cs_theme_options['cs_bgimage_position'] . '"';
        } elseif (isset($cs_theme_options['cs_bg_color']) and $cs_theme_options['cs_bg_color'] <> '') {
            return ' style="background:' . $cs_theme_options['cs_bg_color'] . '"';
        }
    }

}
// Main wrapper class function
if (!function_exists('cs_wrapper_class')) {

    function cs_wrapper_class() {
        global $cs_theme_options;

        if (isset($_POST['cs_layout'])) {

            $_SESSION['lmssess_layout_option'] = $_POST['cs_layout'];
            echo cs_allow_special_char($_SESSION['lmssess_layout_option']);
        } elseif (isset($_SESSION['lmssess_layout_option']) and ! empty($_SESSION['lmssess_layout_option'])) {

            echo cs_allow_special_char($_SESSION['lmssess_layout_option']);
        } else {
            echo cs_allow_special_char($cs_theme_options['cs_layout']);
            $_SESSION['lmssess_layout_option'] = '';
        }
    }

}
// custom sidebar start
$cs_theme_sidebar = get_option('cs_theme_options');
if (isset($cs_theme_sidebar['sidebar']) and ! empty($cs_theme_sidebar['sidebar'])) {
	$cs_theme_options = get_option('cs_theme_options');
    foreach ($cs_theme_sidebar['sidebar'] as $sidebar) {
        $sidebar_id = strtolower(str_replace(' ', '_', $sidebar));
        //foreach ( $parts as $val ) {
		$cs_widget_start = '<div class="widget %2$s">';
		$cs_widget_end = '</div>';
		
		if( isset($cs_theme_options['cs_footer_widget_sidebar']) && $cs_theme_options['cs_footer_widget_sidebar'] == $sidebar ) {
			
			$cs_widget_start = '<aside class="widget col-md-3 %2$s">';
			$cs_widget_end = '</aside>';
		}
        register_sidebar(array(
            'name' => $sidebar,
            'id' => $sidebar_id,
            'description' => esc_html__('This widget will be displayed on right/left side of the page.', 'logistic'),
            'before_widget' => $cs_widget_start,
            'after_widget' => $cs_widget_end,
            'before_title' => '<div class="widget-section-title"><h4>',
            'after_title' => '</h4></div>'
        ));
    }
}
// custom sidebar end
//primary widget
register_sidebar(array(
    'name' => esc_html__('Primary Sidebar', 'logistic'),
    'id' => 'sidebar-1',
    'description' => esc_html__('Main sidebar that appears on the right.', 'logistic'),
    'before_widget' => '<div class="widget %2$s">',
    'after_widget' => '</div>',
    'before_title' => '<div class="widget-section-title"><h4>',
    'after_title' => '</h4></div>'
));
/**
 * @footer widget Area
 *
 *
 */
 
register_sidebar(array(
    'name' => 'Footer Widget',
    'id' => 'footer-widget-1',
    'description' => esc_html__('This Widget Show the Content in Footer Area.', 'logistic'),
    'before_widget' => '<div class="widget col-md-3 %2$s">',
    'after_widget' => '</div>',
    'before_title' => '<div class="widget-title"><h4>',
    'after_title' => '</h4></div>'
));





if (!function_exists('cs_get_sidebar_id')) :

    function cs_get_sidebar_id( $sidebar ) {
		$sidebar_id = strtolower(str_replace(' ', '_', $sidebar));
		return $sidebar_id;
	}
endif;	
		
if (!function_exists('cs_comment')) :

    /**
     * Template for comments and pingbacks.
     *
     * To override this walker in a child theme without modifying the comments template
     * simply create your own cs_comment(), and that function will be used instead.
     *
     * Used as a callback by wp_list_comments() for displaying the comments.
     *
     */
    function cs_comment($comment, $args, $depth) {
        $GLOBALS['comment'] = $comment;
        $args['reply_text'] = esc_html__('Reply', 'logistic');
		
     
        switch ($comment->comment_type) :
            case '' :
			global $cs_single_view,$post;
		 
			?>         
            	<li id="li-comment-<?php comment_ID(); ?>" class="classic-form">
                    <div id="comment-<?php comment_ID(); ?>" class="thumblist">
                        <figure><?php echo get_avatar($comment, 40); ?></figure>
                        <div class="cs-text">
                       <strong><a href="<?php echo esc_url(get_author_posts_url(get_the_author_meta('ID'))); ?>"><?php comment_author(); ?></a></strong><?php comment_text(); ?></p>
                        <span><i class="icon-clock7"></i><?php echo get_comment_date(); ?></span> 
                       <!-- <a href="#"><i class=" icon-dot"></i>Reply User</a> -->
                         <?php comment_reply_link(array_merge($args, array('depth' => $depth)));  ?>
                        </div>
                    </div>
                      
                    
				<?php
                break;
                case 'pingback' :
                case 'trackback' :
                ?>
                <li class="post pingback">
                    <p><?php comment_author_link(); ?><?php edit_comment_link(esc_html__('Edit', 'logistic'), ' '); ?></p>
                <?php
                break;
        endswitch;
    }

endif;



if (!function_exists('cs_under_construction')) {

    function cs_under_construction() {
        global $cs_theme_options, $post, $cs_uc_options;
        $cs_uc_options = get_option('cs_theme_options');
		
        if (isset($post)) {
            $post_name = $post->post_name;
        } else {
            $post_name = '';
        }
	 
	      $cs_maintenance_page_switch = isset($cs_uc_options['cs_maintenance_page_switch']) ? $cs_uc_options['cs_maintenance_page_switch'] : 'off';
		
        if (($cs_maintenance_page_switch == "on" and ! (is_user_logged_in())) or $post_name == "pf-under-construction") {
			 $launch_date = trim($cs_uc_options['cs_launch_date']);
			 
			 $bg='';
			 if (isset($cs_uc_options['cs_maintenance_custom_background']) && $cs_uc_options['cs_maintenance_custom_background'] <> "") {
				 $bg = $cs_uc_options['cs_maintenance_custom_background'];
			 }
			 ?>        
               <main id="main-content">
        			<div class="main-section">
            		<div class="page-section">
                	<section class="construction" style="background:url('<?php echo esc_url($bg);?>') !important;">
                    	<div class="overlay">
                            <div class="container">
                                <div class="row">
                                    
                                    
                                    
                                    <?php 
											if (isset($cs_uc_options['cs_maintenance_logo_switch']) and $cs_uc_options['cs_maintenance_logo_switch'] == "on") {
												if (isset($cs_uc_options['cs_maintenance_custom_logo'])) {
												echo '<div class="construct-logo"><img src="' . esc_url($cs_uc_options['cs_maintenance_custom_logo']) . '" alt="Under maintenance" /></div>';
                                            } else {
													cs_logo();
													}
												} else {
												echo '<a href="' . esc_url(home_url('/')) . '"><i class="icon-cog3"></i></a>';
                                            }
                                            ?>
                                    
                                    
                                    
                                    
                                     <?PHP if(isset($cs_uc_options['cs_maintenance_text']) && $cs_uc_options['cs_maintenance_text'] <> ""){
												  
												    echo stripslashes(htmlspecialchars_decode($cs_uc_options['cs_maintenance_text']));
											}?>
                                            
                                    			<div class="date"></div>
                                    
                                    		<?php 
													$aLaunchDate = explode("/",$launch_date);
													$splitedDay =   $aLaunchDate[0]; 
													$splitedMonth =   $aLaunchDate[1];
													$splitedYear =   $aLaunchDate[2];
													$newLaunchDate =  $splitedYear.'/'.$splitedMonth.'/'.$splitedDay;
                                                ?>
                                                <script type="text/javascript">
                                                jQuery(document).ready(function(){
                                                
                                                
                                                var endDate = '<?php echo esc_attr($newLaunchDate);?>'; // you can set date and time both or any one of those.
                                                var element = '.date'; // set class or id name.
                                                
                                                if(element.length != ''){
                                                
                                                var timeInterval = setInterval(function(){ 
                                                
                                                // converting milliseconds into seperate units
                                                
                                                var seconds = 1000;
                                                var minutes = seconds * 60;
                                                var hours = minutes * 60;
                                                var days = hours * 24;
                                                var months = days * 30;
                                                var years = days * 365;
                                                
                                                // getting end and start times
                                                
                                                var startTime = new Date();
                                                var endTime = new Date(endDate);
                                                
                                                // checking endtime should be greater than current time 
                                                
                                                if(startTime >= endTime){
                                                
                                                jQuery(element).html('Time has Reached! Wait for A While.');
                                                clearInterval(timeInterval);
                                                
                                                }else{
                                                
                                                // getting difference in time 
                                                
                                                var timeDiff = endTime.getTime()-startTime.getTime();
                                                
                                                // converting difference in time into seperate units
                                                
                                                var secondsLeft= Math.floor(timeDiff/seconds);
                                                var minutesLeft= Math.floor(timeDiff/minutes);
                                                var hoursLeft= Math.floor(timeDiff/hours);
                                                var daysLeft= Math.floor(timeDiff/days);
                                                var monthsLeft= Math.floor(timeDiff/months);
                                                var yearsLeft= Math.floor(timeDiff/years);
                                                
                                                // time should not exceed its unit limit
                                                
                                                var secondsRem = secondsLeft % 60;
                                                var minutesRem = minutesLeft % 60;
                                                var hoursRem = hoursLeft % 24;
                                                var daysRem = daysLeft % 31;
                                                var monthsRem = monthsLeft % 12;
                                                var yearsRem = yearsLeft % 365;
                                                
                                                // html structure for putting data
                                                
                                                var secondsHtml = '<span class="seconds"> <span class="digit">'+secondsRem+'</span> <span class="unit">Seconds</span></span>';
                                                var minutesHtml = '<span class="minutes"> <span class="digit">'+minutesRem+'</span> <span class="unit">Minutes</span></span>';
                                                var hoursHtml = '<span class="hours"> <span class="digit">'+hoursRem+'</span> <span class="unit">Hours</span></span>';
                                                var daysHtml = '<span class="days"> <span class="digit">'+daysRem+'</span> <span class="unit">Days</span></span>';
                                                var monthsHtml = '<span class="months"> <span class="digit">'+monthsRem+'</span> <span class="unit">Months</span></span>';
                                                var yearsHtml = '<span class="years"> <span class="digit">'+yearsRem+'</span> <span class="unit">Years</span></span>';
                                                
                                                // if any unit reaches to '0' it won't show
                                                
                                                if(secondsLeft > 0){
                                                
                                                secondsLeft = secondsLeft % 60;
                                                jQuery(element).html(secondsHtml);
                                                
                                                if( minutesLeft > 0){
                                                
                                                minutesLeft = minutesLeft % 60;
                                                jQuery(element).html(minutesHtml+''+secondsHtml);
                                                
                                                if( hoursLeft > 0){
                                                
                                                hoursLeft = hoursLeft % 24;
                                                jQuery(element).html(hoursHtml+''+minutesHtml+''+secondsHtml);
                                                
                                                if( daysLeft > 0){
                                                
                                                daysLeft = daysLeft % 31;
                                                jQuery(element).html(daysHtml+''+hoursHtml+''+minutesHtml+''+secondsHtml);
                                                
                                                if( monthsLeft > 0){
                                                
                                                monthsLeft = monthsLeft % 12;
                                                jQuery(element).html(monthsHtml+''+daysHtml+''+hoursHtml+''+minutesHtml+''+secondsHtml);
                                                
                                                if( yearsLeft > 0){
                                                
                                                yearsLeft = yearsLeft % 365;
                                                jQuery(element).html(yearsHtml+''+monthsHtml+''+daysHtml+''+hoursHtml+''+minutesHtml+''+secondsHtml);
                                                }
                                                }
                                                }
                                                }
                                                }
                                                }
                                                }
                                                }, 1000);
                                                }
                                                });
                                                </script>
                                    
                                    
                                    
                                    
                                    <div class="cs-detail">
                                    	<?php
										
											if (isset($cs_uc_options['cs_maintenance_subscriber_field_switch']) and $cs_uc_options['cs_maintenance_subscriber_field_switch'] == "on") {
												
											?>
                                            <?php    
                                                
													if ( function_exists( 'cs_custom_mailchimp_underconstruction' ) ) {
													
													 	 echo cs_custom_mailchimp_underconstruction();
												   }
                                                
                                                ?>		   
                                    <?php }?>
                                        
                                         <aside class="cs-right">
                                        	<ul class="social-icons">
                                            	<?php 
													if (isset($cs_uc_options['cs_maintenance_social_icons_switch']) and $cs_uc_options['cs_maintenance_social_icons_switch'] == "on") {
														if ( function_exists( 'cs_social_network' ) ) { cs_social_network('','yes'); }
													} 	 
													?>  
                                                
                                            </ul>
                                        </aside>
                                    </div>
                                </div>
                            </div>
                    	</div>
                    </section>
                </div>
            </div>
        </main>
                    
                     <?php
                    die();
                }
            }

        }
		
		
		
		
		
// breadcrumb function
        if (!function_exists('cs_breadcrumbs')) {

            function cs_breadcrumbs($cs_bread_align = 'align-right') {
                global $wp_query, $cs_theme_options, $post;
                /* === OPTIONS === */
                $text['home'] = '<i class="icon-home"></i> ' . esc_html__('Home', 'logistic'); // text for the 'Home' link
                $text['category'] = '%s'; // text for a category page
                $text['search'] = '%s'; // text for a search results page
                $text['tag'] = '%s'; // text for a tag page
                $text['author'] = '%s'; // text for an author page
                $text['404'] = 'Error 404'; // text for the 404 page

                $showCurrent = 1; // 1 - show current post/page title in breadcrumbs, 0 - don't show
                $showOnHome = 1; // 1 - show breadcrumbs on the homepage, 0 - don't show
                $delimiter = ''; // delimiter between crumbs
                $before = '<li class="active">'; // tag before the current crumb
                $after = '</li>'; // tag after the current crumb
                /* === END OF OPTIONS === */
                $current_page = esc_html__('Current Page', 'logistic');
                $homeLink = home_url('/') . '/';
                $linkBefore = '<li>';
                $linkAfter = '</li>';
                $linkAttr = '';
                $link = $linkBefore . '<a' . $linkAttr . ' href="%1$s">%2$s</a>' . $linkAfter;
                $linkhome = $linkBefore . '<a' . $linkAttr . ' href="%1$s">%2$s</a>' . $linkAfter;

                if (is_home() || is_front_page()) {

                    if ($showOnHome == "1")
                        echo '<ul class="breadcrumbs '.$cs_bread_align.'"' . $before . '<li><a href="' . esc_url($homeLink) . '">' . $text['home'] . '</a>' . $after . '</li></ul>';
                } else {
                    echo '<ul class="breadcrumbs '.$cs_bread_align.'">' . sprintf($linkhome, $homeLink, $text['home']) . $delimiter;
                    if (is_category()) {
                        $thisCat = get_category(get_query_var('cat'), false);
                        if ($thisCat->parent != 0) {
                            $cats = get_category_parents($thisCat->parent, TRUE, $delimiter);
                            $cats = str_replace('<a', $linkBefore . '<a' . $linkAttr, $cats);
                            $cats = str_replace('</a>', '</a>' . $linkAfter, $cats);
                            echo esc_attr($cats);
                        }
                        echo cs_allow_special_char($before) . sprintf($text['category'], single_cat_title('', false)) . cs_allow_special_char($after);
                    } elseif (is_search()) {

                        echo cs_allow_special_char($before) . sprintf($text['search'], get_search_query()) . $after;
                    } elseif (is_day()) {

                        echo sprintf($link, get_year_link(get_the_time('Y')), get_the_time('Y')) . $delimiter;
                        echo sprintf($link, get_month_link(get_the_time('Y'), get_the_time('m')), get_the_time('F')) . $delimiter;
                        echo cs_allow_special_char($before) . get_the_time('d') . $after;
                    } elseif (is_month()) {

                        echo sprintf($link, get_year_link(get_the_time('Y')), get_the_time('Y')) . $delimiter;
                        echo cs_allow_special_char($before) . get_the_time('F') . $after;
                    } elseif (is_year()) {

                        echo cs_allow_special_char($before) . get_the_time('Y') . $after;
                    } elseif (is_single() && !is_attachment()) {

                        if (get_post_type() != 'post') {
                            $post_type = get_post_type_object(get_post_type());
                            $slug = $post_type->rewrite;
                            printf($link, $homeLink . '/' . $slug['slug'] . '/', $post_type->labels->singular_name);
                            if ($showCurrent == 1)
                                echo cs_allow_special_char($delimiter) . $before . $current_page . $after;
                        } else {

                            $cat = get_the_category();
                            $cat = $cat[0];
                            $cats = get_category_parents($cat, TRUE, $delimiter);
                            if ($showCurrent == 0)
                                $cats = preg_replace("#^(.+)$delimiter$#", "$1", $cats);
                            $cats = str_replace('<a', $linkBefore . '<a' . $linkAttr, $cats);
                            $cats = str_replace('</a>', '</a>' . $linkAfter, $cats);
                            echo cs_allow_special_char($cats);

                            if ($showCurrent == 1)
                                echo cs_allow_special_char($before) . $current_page . $after;
                        }
                    } elseif (!is_single() && !is_page() && get_post_type() <> '' && get_post_type() != 'post' && !is_404()) {

                        $post_type = get_post_type_object(get_post_type());
                        echo cs_allow_special_char($before) . $post_type->labels->singular_name . $after;
                    } elseif (isset($wp_query->query_vars['taxonomy']) && !empty($wp_query->query_vars['taxonomy'])) {

                        $taxonomy = $taxonomy_category = '';
                        $taxonomy = $wp_query->query_vars['taxonomy'];
                        echo cs_allow_special_char($before) . $wp_query->query_vars[$taxonomy] . $after;
                    } elseif (is_page() && !$post->post_parent) {

                        if ($showCurrent == 1)
                            echo cs_allow_special_char($before) . get_the_title() . $after;
                    } elseif (is_page() && $post->post_parent) {
						
                        $parent_id = $post->post_parent;
                        $breadcrumbs = array();
                        while ($parent_id) {
                            $page = get_page($parent_id);
                            $breadcrumbs[] = sprintf($link, get_permalink($page->ID), get_the_title($page->ID));
                            $parent_id = $page->post_parent;
                        }
                        $breadcrumbs = array_reverse($breadcrumbs);
                        for ($i = 0; $i < count($breadcrumbs); $i++) {
                            echo cs_allow_special_char($breadcrumbs[$i]);
                            if ($i != count($breadcrumbs) - 1)
								echo cs_allow_special_char($delimiter);
                        }
                        if ($showCurrent == 1)
                            echo cs_allow_special_char($delimiter . $before . get_the_title() . $after);
                    } elseif (is_tag()) {

                        echo cs_allow_special_char($before) . sprintf($text['tag'], single_tag_title('', false)) . $after;
                    } elseif (is_author()) {

                        global $author;
                        $userdata = get_userdata($author);
                        echo cs_allow_special_char($before) . sprintf($text['author'], $userdata->display_name) . $after;
                    } elseif (is_404()) {

                        echo cs_allow_special_char($before) . $text['404'] . $after;
                    }
                    echo '</ul>';
                }
            }

        }
        /**
         * @Footer Logo 
         *
         *
         */
        if (!function_exists('cs_footer_logo')) {

            function cs_footer_logo() {
                global $cs_theme_options;
                $logo = $cs_theme_options['cs_footer_logo'];
                $tripadvisor_logo_link = $cs_theme_options['cs_tripadvisor_logo_link'];
                if ($logo <> '') {
                    echo '<a href="' . esc_url($tripadvisor_logo_link) . '"><img src="' . esc_url($logo) . '" alt="' . get_bloginfo('name') . '"></a>';
                }
            }

        }

        if (!function_exists('cs_next_prev_post')) {

            function cs_next_prev_post() {
                global $post;
                posts_nav_link();
				// Don't print empty markup if there's nowhere to navigate.
                $previous = ( is_attachment() ) ? get_post($post->post_parent) : get_adjacent_post(false, '', true);
                $next = get_adjacent_post(false, '', false);
                if (!$next && !$previous)
                    return;
                ?>
            <aside class="cs-post-sharebtn">
            <?php
            previous_posts_link('%link', '<i class="icon-angle-left"></i>');
            next_posts_link('%link', '<i class="icon-angle-right"></i>');
            ?>
            </aside>
            <?php
        }

    }
     function my_function_admin_bar(){
	 return false;
	}
//add_filter( 'show_admin_bar' , 'my_function_admin_bar');


function categories_postcount_filter($variable) {
	$variable = str_replace('(', '<span class="post_count">(', $variable);
	$variable = str_replace(')', ')</span>', $variable);
	return $variable;
}

add_filter('wp_list_categories', 'categories_postcount_filter');

function cs_include_file( $file_path = '' ) {
	
	if( $file_path != '' ) {
    	require_once $file_path;
	}
}
